@@ -1,10 +1,8 @@
-from . import middleware
 from .applications import TApp
 from .routing import Router
 
-__version__ = "1.0"
+__version__ = "1.1"
 __all__ = (
-    "middleware",
     "TApp",
     "Router",
 )
