@@ -1,4 +1,4 @@
 from logging import INFO, basicConfig, getLogger
 
 basicConfig(level=INFO, format="%(asctime)s %(name)s %(levelname)s: %(message)s")
-logger = getLogger("likeapp")
+logger = getLogger("tapp")
