@@ -1,9 +1,7 @@
 from .decorated import Decorated
-from .event import EventProtocol
 from .filter import Filter
 
 __all__ = (
     "Decorated",
-    "EventProtocol",
     "Filter",
 )
